.. toctree::
   :maxdepth: 2

Transport tweaks
----------------

.. include:: /../../examples/v3arch/asyncore/manager/cmdgen/custom-timeout-and-retries.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v3arch/asyncore/manager/cmdgen/custom-timeout-and-retries.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v3arch/asyncore/manager/cmdgen/custom-timeout-and-retries.py>` script.


.. include:: /../../examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v3arch/asyncore/manager/cmdgen/send-packets-from-specific-interface.py>` script.


.. include:: /../../examples/v3arch/asyncore/manager/cmdgen/spoof-source-address.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v3arch/asyncore/manager/cmdgen/spoof-source-address.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v3arch/asyncore/manager/cmdgen/spoof-source-address.py>` script.


.. include:: /../../examples/v3arch/asyncore/manager/cmdgen/fetch-variables-over-ipv6.py
   :start-after: """
   :end-before: """#

.. literalinclude:: /../../examples/v3arch/asyncore/manager/cmdgen/fetch-variables-over-ipv6.py
   :start-after: """#
   :language: python

:download:`Download</../../examples/v3arch/asyncore/manager/cmdgen/fetch-variables-over-ipv6.py>` script.


See also: :doc:`library-reference </docs/api-reference>`.
